@@ -4,6 +4,7 @@ use warnings;
 use Test::More;
 use Test::TCP;
 use File::Which qw(which);
+use FindBin qw/$Bin/;
 
 use base qw(Exporter);
 our @EXPORT = qw(test_qserver);
@@ -21,8 +22,11 @@ sub test_qserver(&;$) {
     test_tcp
         server => sub {
             my $port = shift;
+
             open STDOUT, '>', '/dev/null' or die q/Can't redirect STDOUT/;
             open STDERR, '>', '/dev/null' or die q/Can't redirect STDERR/;
+
+            exec 'q', "$Bin/q/hang.q", '-p', $port if $args->{hang};
             exec 'q', '-p', $port;
         },
         client => sub {
